# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v2/tenant_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v2 import tenant_pb2 as nebius_dot_iam_dot_v2_dot_tenant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nebius/iam/v2/tenant_service.proto\x12\rnebius.iam.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1anebius/iam/v2/tenant.proto\"\"\n\x10GetTenantRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Q\n\x16GetTenantByNameRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\xa5\x01\n\x13UpdateTenantRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12-\n\x04spec\x18\x02 \x01(\x0b\x32\x19.nebius.iam.v2.TenantSpecR\x04spec\x12\x1f\n\x0bname_prefix\x18\x03 \x01(\tR\nnamePrefix\"h\n\x12ListTenantsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x03 \x01(\tR\x06\x66ilter\"j\n\x13ListTenantsResponse\x12+\n\x05items\x18\x01 \x03(\x0b\x32\x15.nebius.iam.v2.TenantR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xbf\x02\n\rTenantService\x12=\n\x03Get\x12\x1f.nebius.iam.v2.GetTenantRequest\x1a\x15.nebius.iam.v2.Tenant\x12I\n\tGetByName\x12%.nebius.iam.v2.GetTenantByNameRequest\x1a\x15.nebius.iam.v2.Tenant\x12M\n\x04List\x12!.nebius.iam.v2.ListTenantsRequest\x1a\".nebius.iam.v2.ListTenantsResponse\x12I\n\x06Update\x12\".nebius.iam.v2.UpdateTenantRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamBY\n\x14\x61i.nebius.pub.iam.v2B\x12TenantServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v2.tenant_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v2B\022TenantServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v2'
  _GETTENANTBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETTENANTBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _TENANTSERVICE._options = None
  _TENANTSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_GETTENANTREQUEST']._serialized_start=203
  _globals['_GETTENANTREQUEST']._serialized_end=237
  _globals['_GETTENANTBYNAMEREQUEST']._serialized_start=239
  _globals['_GETTENANTBYNAMEREQUEST']._serialized_end=320
  _globals['_UPDATETENANTREQUEST']._serialized_start=323
  _globals['_UPDATETENANTREQUEST']._serialized_end=488
  _globals['_LISTTENANTSREQUEST']._serialized_start=490
  _globals['_LISTTENANTSREQUEST']._serialized_end=594
  _globals['_LISTTENANTSRESPONSE']._serialized_start=596
  _globals['_LISTTENANTSRESPONSE']._serialized_end=702
  _globals['_TENANTSERVICE']._serialized_start=705
  _globals['_TENANTSERVICE']._serialized_end=1024
# @@protoc_insertion_point(module_scope)
