# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/postgresql/v1alpha1/config/postgresql.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6nebius/msp/postgresql/v1alpha1/config/postgresql.proto\x12%nebius.msp.postgresql.v1alpha1.config\x1a\x1b\x62uf/validate/validate.proto\"\xf6\t\n\x12PostgresqlConfig16\x12K\n\x13\x61utovacuum_work_mem\x18\x01 \x01(\x03\x42\x16\xbaH\x13\"\x11\x18\xff\xff\xff\xff\x07(\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01H\x00R\x11\x61utovacuumWorkMem\x88\x01\x01\x12?\n\x11statement_timeout\x18\x02 \x01(\x03\x42\r\xbaH\n\"\x08\x18\xff\xff\xff\xff\x07(\x00H\x01R\x10statementTimeout\x88\x01\x01\x12`\n#idle_in_transaction_session_timeout\x18\x03 \x01(\x03\x42\r\xbaH\n\"\x08\x18\xff\xff\xff\xff\x07(\x00H\x02R\x1fidleInTransactionSessionTimeout\x88\x01\x01\x12X\n\x1c\x61utovacuum_vacuum_cost_delay\x18\x04 \x01(\x03\x42\x12\xbaH\x0f\"\r\x18\x64(\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01H\x03R\x19\x61utovacuumVacuumCostDelay\x88\x01\x01\x12Y\n\x1c\x61utovacuum_vacuum_cost_limit\x18\x05 \x01(\x03\x42\x13\xbaH\x10\"\x0e\x18\x90N(\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01H\x04R\x19\x61utovacuumVacuumCostLimit\x88\x01\x01\x12@\n\x12\x61utovacuum_naptime\x18\x06 \x01(\x03\x42\x0c\xbaH\t\"\x07\x18\x9b\x89\x83\x01(\x01H\x05R\x11\x61utovacuumNaptime\x88\x01\x01\x12\x61\n\x1e\x61utovacuum_vacuum_scale_factor\x18\x07 \x01(\x01\x42\x17\xbaH\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00Y@)\x00\x00\x00\x00\x00\x00\x00\x00H\x06R\x1b\x61utovacuumVacuumScaleFactor\x88\x01\x01\x12\x63\n\x1f\x61utovacuum_analyze_scale_factor\x18\x08 \x01(\x01\x42\x17\xbaH\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00Y@)\x00\x00\x00\x00\x00\x00\x00\x00H\x07R\x1c\x61utovacuumAnalyzeScaleFactor\x88\x01\x01\x12\x46\n\x1d\x64\x65\x66\x61ult_transaction_read_only\x18\t \x01(\x08H\x08R\x1a\x64\x65\x66\x61ultTransactionReadOnly\x88\x01\x01\x12$\n\x0bsearch_path\x18\n \x01(\tH\tR\nsearchPath\x88\x01\x01\x12\x38\n\x0fmax_connections\x18\x0b \x01(\x03\x42\n\xbaH\x07\"\x05\x18\x80\x64(dH\nR\x0emaxConnections\x88\x01\x01\x12:\n\x0eshared_buffers\x18\x0c \x01(\x03\x42\x0e\xbaH\x0b\"\t\x18\xf8\xff\xff\xff\x1f(\x80\x01H\x0bR\rsharedBuffers\x88\x01\x01\x42\x16\n\x14_autovacuum_work_memB\x14\n\x12_statement_timeoutB&\n$_idle_in_transaction_session_timeoutB\x1f\n\x1d_autovacuum_vacuum_cost_delayB\x1f\n\x1d_autovacuum_vacuum_cost_limitB\x15\n\x13_autovacuum_naptimeB!\n\x1f_autovacuum_vacuum_scale_factorB\"\n _autovacuum_analyze_scale_factorB \n\x1e_default_transaction_read_onlyB\x0e\n\x0c_search_pathB\x12\n\x10_max_connectionsB\x11\n\x0f_shared_buffersB\x86\x01\n,ai.nebius.pub.msp.postgresql.v1alpha1.configB\x0fPostgresqlProtoP\x01ZCgithub.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1/configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.postgresql.v1alpha1.config.postgresql_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,ai.nebius.pub.msp.postgresql.v1alpha1.configB\017PostgresqlProtoP\001ZCgithub.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1/config'
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_work_mem']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_work_mem']._serialized_options = b'\272H\023\"\021\030\377\377\377\377\007(\377\377\377\377\377\377\377\377\377\001'
  _POSTGRESQLCONFIG16.fields_by_name['statement_timeout']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['statement_timeout']._serialized_options = b'\272H\n\"\010\030\377\377\377\377\007(\000'
  _POSTGRESQLCONFIG16.fields_by_name['idle_in_transaction_session_timeout']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\272H\n\"\010\030\377\377\377\377\007(\000'
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_vacuum_cost_delay']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_vacuum_cost_delay']._serialized_options = b'\272H\017\"\r\030d(\377\377\377\377\377\377\377\377\377\001'
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_vacuum_cost_limit']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_vacuum_cost_limit']._serialized_options = b'\272H\020\"\016\030\220N(\377\377\377\377\377\377\377\377\377\001'
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_naptime']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_naptime']._serialized_options = b'\272H\t\"\007\030\233\211\203\001(\001'
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_vacuum_scale_factor']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_vacuum_scale_factor']._serialized_options = b'\272H\024\022\022\031\000\000\000\000\000\000Y@)\000\000\000\000\000\000\000\000'
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_analyze_scale_factor']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['autovacuum_analyze_scale_factor']._serialized_options = b'\272H\024\022\022\031\000\000\000\000\000\000Y@)\000\000\000\000\000\000\000\000'
  _POSTGRESQLCONFIG16.fields_by_name['max_connections']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['max_connections']._serialized_options = b'\272H\007\"\005\030\200d(d'
  _POSTGRESQLCONFIG16.fields_by_name['shared_buffers']._options = None
  _POSTGRESQLCONFIG16.fields_by_name['shared_buffers']._serialized_options = b'\272H\013\"\t\030\370\377\377\377\037(\200\001'
  _globals['_POSTGRESQLCONFIG16']._serialized_start=127
  _globals['_POSTGRESQLCONFIG16']._serialized_end=1397
# @@protoc_insertion_point(module_scope)
