# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/maintenance/v1alpha1/maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-nebius/maintenance/v1alpha1/maintenance.proto\x12\x1bnebius.maintenance.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe7\x01\n\x0bMaintenance\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.maintenance.v1alpha1.MaintenanceSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32..nebius.maintenance.v1alpha1.MaintenanceStatusR\x06status\"X\n\x0fMaintenanceSpec\x12\x45\n\x0cscheduled_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0bscheduledAt\"\xc9\x02\n\x11MaintenanceStatus\x12T\n\x12\x61\x66\x66\x65\x63ted_resources\x18\x01 \x03(\x0b\x32%.nebius.maintenance.v1alpha1.ResourceR\x11\x61\x66\x66\x65\x63tedResources\x12\x39\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartedAt\x12;\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nfinishedAt\x12@\n\x05state\x18\x04 \x01(\x0e\x32\".nebius.maintenance.v1alpha1.StateB\x06\xbaH\x03\xc8\x01\x01R\x05state\x12$\n\rreschedulable\x18\x05 \x01(\x08R\rreschedulable\"G\n\x08Resource\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12#\n\tparent_id\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId*\x84\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_SCHEDULED\x10\x01\x12\x15\n\x11STATE_IN_PROGRESS\x10\x02\x12\x12\n\x0eSTATE_FINISHED\x10\x03\x12\x0f\n\x0bSTATE_ERROR\x10\x04\x12\x13\n\x0fSTATE_CANCELLED\x10\x05\x42s\n\"ai.nebius.pub.maintenance.v1alpha1B\x10MaintenanceProtoP\x01Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.maintenance.v1alpha1.maintenance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"ai.nebius.pub.maintenance.v1alpha1B\020MaintenanceProtoP\001Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1'
  _MAINTENANCE.fields_by_name['metadata']._options = None
  _MAINTENANCE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _MAINTENANCE.fields_by_name['spec']._options = None
  _MAINTENANCE.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _MAINTENANCESPEC.fields_by_name['scheduled_at']._options = None
  _MAINTENANCESPEC.fields_by_name['scheduled_at']._serialized_options = b'\272H\003\310\001\001'
  _MAINTENANCESTATUS.fields_by_name['state']._options = None
  _MAINTENANCESTATUS.fields_by_name['state']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCE.fields_by_name['id']._options = None
  _RESOURCE.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCE.fields_by_name['parent_id']._options = None
  _RESOURCE.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_STATE']._serialized_start=903
  _globals['_STATE']._serialized_end=1035
  _globals['_MAINTENANCE']._serialized_start=174
  _globals['_MAINTENANCE']._serialized_end=405
  _globals['_MAINTENANCESPEC']._serialized_start=407
  _globals['_MAINTENANCESPEC']._serialized_end=495
  _globals['_MAINTENANCESTATUS']._serialized_start=498
  _globals['_MAINTENANCESTATUS']._serialized_end=827
  _globals['_RESOURCE']._serialized_start=829
  _globals['_RESOURCE']._serialized_end=900
# @@protoc_insertion_point(module_scope)
