# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.audit.v2 import resource_metadata_pb2 as nebius_dot_audit_dot_v2_dot_resource__metadata__pb2
from nebius.api.nebius.audit.v2 import resource_state_pb2 as nebius_dot_audit_dot_v2_dot_resource__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/audit/v2/resource.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\'nebius/audit/v2/resource_metadata.proto\x1a$nebius/audit/v2/resource_state.proto\"\xc8\x01\n\x08Resource\x12\x45\n\x08metadata\x18\x01 \x01(\x0b\x32!.nebius.audit.v2.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x34\n\x05state\x18\x02 \x01(\x0b\x32\x1e.nebius.audit.v2.ResourceStateR\x05state\x12?\n\thierarchy\x18\x03 \x03(\x0b\x32!.nebius.audit.v2.ResourceMetadataR\thierarchyBX\n\x16\x61i.nebius.pub.audit.v2B\rResourceProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\rResourceProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _RESOURCE.fields_by_name['metadata']._options = None
  _RESOURCE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_RESOURCE']._serialized_start=160
  _globals['_RESOURCE']._serialized_end=360
# @@protoc_insertion_point(module_scope)
