# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/v1alpha1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/msp/v1alpha1/cluster.proto\x12\x13nebius.msp.v1alpha1\"\xfd\x03\n\rClusterStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12 \n\x0breconciling\x18\x64 \x01(\x08R\x0breconciling\"\xc3\x01\n\x05Phase\x12\x15\n\x11PHASE_UNSPECIFIED\x10\x00\x12\x16\n\x12PHASE_PROVISIONING\x10\x01\x12\x11\n\rPHASE_RUNNING\x10\x02\x12\x12\n\x0ePHASE_UPDATING\x10\x03\x12\x12\n\x0ePHASE_DELETING\x10\x04\x12\x15\n\rPHASE_DELETED\x10\x05\x1a\x02\x08\x01\x12\x11\n\rPHASE_PURGING\x10\x06\x12\x12\n\x0ePHASE_STOPPING\x10\x07\x12\x12\n\x0ePHASE_RESUMING\x10\x08\"\x83\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11STATE_IN_PROGRESS\x10\x01\x12\x12\n\x0eSTATE_FINISHED\x10\x02\x12\x0f\n\x0bSTATE_ERROR\x10\x03\x12\x12\n\x0eSTATE_DEGRADED\x10\x04\x12\x13\n\x0fSTATE_SCHEDULED\x10\x05\x42_\n\x1a\x61i.nebius.pub.msp.v1alpha1B\x0c\x43lusterProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/msp/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.v1alpha1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.msp.v1alpha1B\014ClusterProtoP\001Z1github.com/nebius/gosdk/proto/nebius/msp/v1alpha1'
  _CLUSTERSTATUS_PHASE.values_by_name["PHASE_DELETED"]._options = None
  _CLUSTERSTATUS_PHASE.values_by_name["PHASE_DELETED"]._serialized_options = b'\010\001'
  _globals['_CLUSTERSTATUS']._serialized_start=59
  _globals['_CLUSTERSTATUS']._serialized_end=568
  _globals['_CLUSTERSTATUS_PHASE']._serialized_start=239
  _globals['_CLUSTERSTATUS_PHASE']._serialized_end=434
  _globals['_CLUSTERSTATUS_STATE']._serialized_start=437
  _globals['_CLUSTERSTATUS_STATE']._serialized_end=568
# @@protoc_insertion_point(module_scope)
