# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/invitation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import invitation_pb2 as nebius_dot_iam_dot_v1_dot_invitation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v1/invitation_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v1/invitation.proto\"\xa5\x01\n\x17\x43reateInvitationRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.InvitationSpecR\x04spec\x12\x17\n\x07no_send\x18\x03 \x01(\x08R\x06noSend\".\n\x14GetInvitationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x96\x01\n\x16ListInvitationsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x1b\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xc0J\x01R\x06\x66ilter\"r\n\x17ListInvitationsResponse\x12/\n\x05items\x18\x01 \x03(\x0b\x32\x19.nebius.iam.v1.InvitationR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"1\n\x17\x44\x65leteInvitationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x8c\x01\n\x17UpdateInvitationRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.InvitationSpecR\x04spec\"1\n\x17ResendInvitationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xf9\x03\n\x11InvitationService\x12M\n\x06\x43reate\x12&.nebius.iam.v1.CreateInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x12\x45\n\x03Get\x12#.nebius.iam.v1.GetInvitationRequest\x1a\x19.nebius.iam.v1.Invitation\x12U\n\x04List\x12%.nebius.iam.v1.ListInvitationsRequest\x1a&.nebius.iam.v1.ListInvitationsResponse\x12M\n\x06\x44\x65lete\x12&.nebius.iam.v1.DeleteInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06Update\x12&.nebius.iam.v1.UpdateInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06Resend\x12&.nebius.iam.v1.ResendInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamB]\n\x14\x61i.nebius.pub.iam.v1B\x16InvitationServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.invitation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\026InvitationServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETINVITATIONREQUEST.fields_by_name['id']._options = None
  _GETINVITATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTINVITATIONSREQUEST.fields_by_name['parent_id']._options = None
  _LISTINVITATIONSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTINVITATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTINVITATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\300J\001'
  _DELETEINVITATIONREQUEST.fields_by_name['id']._options = None
  _DELETEINVITATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _RESENDINVITATIONREQUEST.fields_by_name['id']._options = None
  _RESENDINVITATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _INVITATIONSERVICE._options = None
  _INVITATIONSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEINVITATIONREQUEST']._serialized_start=212
  _globals['_CREATEINVITATIONREQUEST']._serialized_end=377
  _globals['_GETINVITATIONREQUEST']._serialized_start=379
  _globals['_GETINVITATIONREQUEST']._serialized_end=425
  _globals['_LISTINVITATIONSREQUEST']._serialized_start=428
  _globals['_LISTINVITATIONSREQUEST']._serialized_end=578
  _globals['_LISTINVITATIONSRESPONSE']._serialized_start=580
  _globals['_LISTINVITATIONSRESPONSE']._serialized_end=694
  _globals['_DELETEINVITATIONREQUEST']._serialized_start=696
  _globals['_DELETEINVITATIONREQUEST']._serialized_end=745
  _globals['_UPDATEINVITATIONREQUEST']._serialized_start=748
  _globals['_UPDATEINVITATIONREQUEST']._serialized_end=888
  _globals['_RESENDINVITATIONREQUEST']._serialized_start=890
  _globals['_RESENDINVITATIONREQUEST']._serialized_end=939
  _globals['_INVITATIONSERVICE']._serialized_start=942
  _globals['_INVITATIONSERVICE']._serialized_end=1447
# @@protoc_insertion_point(module_scope)
