# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/serverless/v1alpha1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.msp.serverless.v1alpha1 import endpoint_pb2 as nebius_dot_msp_dot_serverless_dot_v1alpha1_dot_endpoint__pb2
from nebius.api.nebius.msp.v1alpha1 import common_pb2 as nebius_dot_msp_dot_v1alpha1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nebius/msp/serverless/v1alpha1/endpoint_service.proto\x12\x1enebius.msp.serverless.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a-nebius/msp/serverless/v1alpha1/endpoint.proto\x1a nebius/msp/v1alpha1/common.proto\"\xc2\x01\n\x15\x43reateEndpointRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.msp.serverless.v1alpha1.EndpointSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x17\n\x07\x64ry_run\x18\x03 \x01(\x08R\x06\x64ryRun\"\x7f\n\x15ListEndpointsResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32(.nebius.msp.serverless.v1alpha1.EndpointR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xe8\x04\n\x0f\x45ndpointService\x12P\n\x03Get\x12\x1f.nebius.msp.v1alpha1.GetRequest\x1a(.nebius.msp.serverless.v1alpha1.Endpoint\x12\\\n\tGetByName\x12%.nebius.msp.v1alpha1.GetByNameRequest\x1a(.nebius.msp.serverless.v1alpha1.Endpoint\x12_\n\x04List\x12 .nebius.msp.v1alpha1.ListRequest\x1a\x35.nebius.msp.serverless.v1alpha1.ListEndpointsResponse\x12\\\n\x06\x43reate\x12\x35.nebius.msp.serverless.v1alpha1.CreateEndpointRequest\x1a\x1b.nebius.common.v1.Operation\x12I\n\x06\x44\x65lete\x12\".nebius.msp.v1alpha1.DeleteRequest\x1a\x1b.nebius.common.v1.Operation\x12G\n\x05Start\x12!.nebius.msp.v1alpha1.StartRequest\x1a\x1b.nebius.common.v1.Operation\x12\x45\n\x04Stop\x12 .nebius.msp.v1alpha1.StopRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x0b\xbaJ\x08\x61pps.mspB}\n%ai.nebius.pub.msp.serverless.v1alpha1B\x14\x45ndpointServiceProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.serverless.v1alpha1.endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.serverless.v1alpha1B\024EndpointServiceProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1'
  _CREATEENDPOINTREQUEST.fields_by_name['metadata']._options = None
  _CREATEENDPOINTREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATEENDPOINTREQUEST.fields_by_name['spec']._options = None
  _CREATEENDPOINTREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSERVICE._options = None
  _ENDPOINTSERVICE._serialized_options = b'\272J\010apps.msp'
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=293
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=487
  _globals['_LISTENDPOINTSRESPONSE']._serialized_start=489
  _globals['_LISTENDPOINTSRESPONSE']._serialized_end=616
  _globals['_ENDPOINTSERVICE']._serialized_start=619
  _globals['_ENDPOINTSERVICE']._serialized_end=1235
# @@protoc_insertion_point(module_scope)
