# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/auth_public_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import auth_public_key_pb2 as nebius_dot_iam_dot_v1_dot_auth__public__key__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+nebius/iam/v1/auth_public_key_service.proto\x12\rnebius.iam.v1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a#nebius/iam/v1/auth_public_key.proto\x1a\x1anebius/iam/v1/access.proto\"\x92\x01\n\x1a\x43reateAuthPublicKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32 .nebius.iam.v1.AuthPublicKeySpecR\x04spec\")\n\x17GetAuthPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x9e\x01\n\x18ListAuthPublicKeyRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\xa9\x01\n!ListAuthPublicKeyByAccountRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountR\x07\x61\x63\x63ount\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x92\x01\n\x1aUpdateAuthPublicKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32 .nebius.iam.v1.AuthPublicKeySpecR\x04spec\".\n\x1c\x41\x63tivateAuthPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"0\n\x1e\x44\x65\x61\x63tivateAuthPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\",\n\x1a\x44\x65leteAuthPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"w\n\x19ListAuthPublicKeyResponse\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32\x1c.nebius.iam.v1.AuthPublicKeyR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xdd\x05\n\x14\x41uthPublicKeyService\x12P\n\x06\x43reate\x12).nebius.iam.v1.CreateAuthPublicKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x03Get\x12&.nebius.iam.v1.GetAuthPublicKeyRequest\x1a\x1c.nebius.iam.v1.AuthPublicKey\x12Y\n\x04List\x12\'.nebius.iam.v1.ListAuthPublicKeyRequest\x1a(.nebius.iam.v1.ListAuthPublicKeyResponse\x12k\n\rListByAccount\x12\x30.nebius.iam.v1.ListAuthPublicKeyByAccountRequest\x1a(.nebius.iam.v1.ListAuthPublicKeyResponse\x12P\n\x06Update\x12).nebius.iam.v1.UpdateAuthPublicKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12T\n\x08\x41\x63tivate\x12+.nebius.iam.v1.ActivateAuthPublicKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12X\n\nDeactivate\x12-.nebius.iam.v1.DeactivateAuthPublicKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12P\n\x06\x44\x65lete\x12).nebius.iam.v1.DeleteAuthPublicKeyRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamB`\n\x14\x61i.nebius.pub.iam.v1B\x19\x41uthPublicKeyServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.auth_public_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\031AuthPublicKeyServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _AUTHPUBLICKEYSERVICE._options = None
  _AUTHPUBLICKEYSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEAUTHPUBLICKEYREQUEST']._serialized_start=221
  _globals['_CREATEAUTHPUBLICKEYREQUEST']._serialized_end=367
  _globals['_GETAUTHPUBLICKEYREQUEST']._serialized_start=369
  _globals['_GETAUTHPUBLICKEYREQUEST']._serialized_end=410
  _globals['_LISTAUTHPUBLICKEYREQUEST']._serialized_start=413
  _globals['_LISTAUTHPUBLICKEYREQUEST']._serialized_end=571
  _globals['_LISTAUTHPUBLICKEYBYACCOUNTREQUEST']._serialized_start=574
  _globals['_LISTAUTHPUBLICKEYBYACCOUNTREQUEST']._serialized_end=743
  _globals['_UPDATEAUTHPUBLICKEYREQUEST']._serialized_start=746
  _globals['_UPDATEAUTHPUBLICKEYREQUEST']._serialized_end=892
  _globals['_ACTIVATEAUTHPUBLICKEYREQUEST']._serialized_start=894
  _globals['_ACTIVATEAUTHPUBLICKEYREQUEST']._serialized_end=940
  _globals['_DEACTIVATEAUTHPUBLICKEYREQUEST']._serialized_start=942
  _globals['_DEACTIVATEAUTHPUBLICKEYREQUEST']._serialized_end=990
  _globals['_DELETEAUTHPUBLICKEYREQUEST']._serialized_start=992
  _globals['_DELETEAUTHPUBLICKEYREQUEST']._serialized_end=1036
  _globals['_LISTAUTHPUBLICKEYRESPONSE']._serialized_start=1038
  _globals['_LISTAUTHPUBLICKEYRESPONSE']._serialized_end=1157
  _globals['_AUTHPUBLICKEYSERVICE']._serialized_start=1160
  _globals['_AUTHPUBLICKEYSERVICE']._serialized_end=1893
# @@protoc_insertion_point(module_scope)
