# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/postgresql/v1alpha1/backup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+nebius/msp/postgresql/v1alpha1/backup.proto\x12\x1enebius.msp.postgresql.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x02\n\x06\x42\x61\x63kup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12*\n\x11source_cluster_id\x18\x02 \x01(\tR\x0fsourceClusterId\x12\x41\n\x0e\x63reation_start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreationStart\x12\x43\n\x0f\x63reation_finish\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x63reationFinish\x12.\n\x13source_cluster_name\x18\x05 \x01(\tR\x11sourceClusterName\x12\x34\n\x16source_cluster_visible\x18\x06 \x01(\x08R\x14sourceClusterVisible\x12\x1b\n\ton_demand\x18\x07 \x01(\x08R\x08onDemand\x12\x1d\n\nsize_bytes\x18\x08 \x01(\x03R\tsizeBytesBt\n%ai.nebius.pub.msp.postgresql.v1alpha1B\x0b\x42\x61\x63kupProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.postgresql.v1alpha1.backup_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.postgresql.v1alpha1B\013BackupProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1'
  _globals['_BACKUP']._serialized_start=113
  _globals['_BACKUP']._serialized_end=479
# @@protoc_insertion_point(module_scope)
