# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/suspension_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/iam/v1/suspension_state.proto\x12\rnebius.iam.v1*j\n\x0fSuspensionState\x12 \n\x1cSUSPENSION_STATE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x0e\n\nSUSPENDING\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x12\x0c\n\x08RESUMING\x10\x04\x42[\n\x14\x61i.nebius.pub.iam.v1B\x14SuspensionStateProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.suspension_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\024SuspensionStateProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _globals['_SUSPENSIONSTATE']._serialized_start=55
  _globals['_SUSPENSIONSTATE']._serialized_end=161
# @@protoc_insertion_point(module_scope)
