# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/route_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import route_pb2 as nebius_dot_vpc_dot_v1_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/vpc/v1/route_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x19nebius/vpc/v1/route.proto\")\n\x0fGetRouteRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"X\n\x15GetRouteByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"t\n\x11ListRoutesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"h\n\x12ListRoutesResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x14.nebius.vpc.v1.RouteR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xd7\x02\n\x12\x43reateRouteRequest\x12\x8a\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc9\x01\xbaH\xc5\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xc8\x01\x01R\x08metadata\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.vpc.v1.RouteSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xcc\x02\n\x12UpdateRouteRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.vpc.v1.RouteSpecR\x04spec\",\n\x12\x44\x65leteRouteRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xc7\x03\n\x0cRouteService\x12;\n\x03Get\x12\x1e.nebius.vpc.v1.GetRouteRequest\x1a\x14.nebius.vpc.v1.Route\x12G\n\tGetByName\x12$.nebius.vpc.v1.GetRouteByNameRequest\x1a\x14.nebius.vpc.v1.Route\x12K\n\x04List\x12 .nebius.vpc.v1.ListRoutesRequest\x1a!.nebius.vpc.v1.ListRoutesResponse\x12H\n\x06\x43reate\x12!.nebius.vpc.v1.CreateRouteRequest\x1a\x1b.nebius.common.v1.Operation\x12H\n\x06Update\x12!.nebius.vpc.v1.UpdateRouteRequest\x1a\x1b.nebius.common.v1.Operation\x12H\n\x06\x44\x65lete\x12!.nebius.vpc.v1.DeleteRouteRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcBX\n\x14\x61i.nebius.pub.vpc.v1B\x11RouteServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.route_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\021RouteServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETROUTEREQUEST.fields_by_name['id']._options = None
  _GETROUTEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETROUTEBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETROUTEBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETROUTEBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETROUTEBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTROUTESREQUEST.fields_by_name['parent_id']._options = None
  _LISTROUTESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATEROUTEREQUEST.fields_by_name['metadata']._options = None
  _CREATEROUTEREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\305\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\310\001\001'
  _CREATEROUTEREQUEST.fields_by_name['spec']._options = None
  _CREATEROUTEREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEROUTEREQUEST.fields_by_name['metadata']._options = None
  _UPDATEROUTEREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _DELETEROUTEREQUEST.fields_by_name['id']._options = None
  _DELETEROUTEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ROUTESERVICE._options = None
  _ROUTESERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETROUTEREQUEST']._serialized_start=201
  _globals['_GETROUTEREQUEST']._serialized_end=242
  _globals['_GETROUTEBYNAMEREQUEST']._serialized_start=244
  _globals['_GETROUTEBYNAMEREQUEST']._serialized_end=332
  _globals['_LISTROUTESREQUEST']._serialized_start=334
  _globals['_LISTROUTESREQUEST']._serialized_end=450
  _globals['_LISTROUTESRESPONSE']._serialized_start=452
  _globals['_LISTROUTESRESPONSE']._serialized_end=556
  _globals['_CREATEROUTEREQUEST']._serialized_start=559
  _globals['_CREATEROUTEREQUEST']._serialized_end=902
  _globals['_UPDATEROUTEREQUEST']._serialized_start=905
  _globals['_UPDATEROUTEREQUEST']._serialized_end=1237
  _globals['_DELETEROUTEREQUEST']._serialized_start=1239
  _globals['_DELETEROUTEREQUEST']._serialized_end=1283
  _globals['_ROUTESERVICE']._serialized_start=1286
  _globals['_ROUTESERVICE']._serialized_end=1741
# @@protoc_insertion_point(module_scope)
