# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/offer_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/billing/v1alpha1/offer_type.proto\x12\x17nebius.billing.v1alpha1*F\n\tOfferType\x12\x1a\n\x16OFFER_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19OFFER_TYPE_CONTRACT_PRICE\x10\x01\x42i\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x0eOfferTypeProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.offer_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\016OfferTypeProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _globals['_OFFERTYPE']._serialized_start=69
  _globals['_OFFERTYPE']._serialized_end=139
# @@protoc_insertion_point(module_scope)
