# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.rpc import code_pb2 as google_dot_rpc_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/audit/v2/response.proto\x12\x0fnebius.audit.v2\x1a\x1cgoogle/protobuf/struct.proto\x1a\x15google/rpc/code.proto\"\x95\x01\n\x08Response\x12\x31\n\x0bstatus_code\x18\x01 \x01(\x0e\x32\x10.google.rpc.CodeR\nstatusCode\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\x12\x31\n\x07payload\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07payloadBX\n\x16\x61i.nebius.pub.audit.v2B\rResponseProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\rResponseProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_RESPONSE']._serialized_start=105
  _globals['_RESPONSE']._serialized_end=254
# @@protoc_insertion_point(module_scope)
