# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/error/v1alpha1/common_errors.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0nebius/common/error/v1alpha1/common_errors.proto\x12\x1cnebius.common.error.v1alpha1\x1a\x18nebius/annotations.proto\"\x9d\x01\n\nBadRequest\x12R\n\nviolations\x18\x01 \x03(\x0b\x32\x32.nebius.common.error.v1alpha1.BadRequest.ViolationR\nviolations\x1a;\n\tViolation\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"M\n\x10\x42\x61\x64ResourceState\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"3\n\x10ResourceNotFound\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\"8\n\x15ResourceAlreadyExists\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\"M\n\x10ResourceConflict\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"\x8d\x01\n\x10OperationAborted\x12!\n\x0coperation_id\x18\x01 \x01(\tR\x0boperationId\x12\x35\n\x17\x61\x62orted_by_operation_id\x18\x02 \x01(\tR\x14\x61\x62ortedByOperationId\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tR\nresourceId\"@\n\nOutOfRange\x12\x1c\n\trequested\x18\x01 \x01(\tR\trequested\x12\x14\n\x05limit\x18\x02 \x01(\tR\x05limit\"3\n\x10PermissionDenied\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\"I\n\rInternalError\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x19\n\x08trace_id\x18\x02 \x01(\tR\x07traceId\"/\n\x0fTooManyRequests\x12\x1c\n\tviolation\x18\x01 \x01(\tR\tviolation\"\xd5\x01\n\x0cQuotaFailure\x12T\n\nviolations\x18\x01 \x03(\x0b\x32\x34.nebius.common.error.v1alpha1.QuotaFailure.ViolationR\nviolations\x1ao\n\tViolation\x12\x14\n\x05quota\x18\x01 \x01(\tR\x05quota\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x14\n\x05limit\x18\x03 \x01(\tR\x05limit\x12\x1c\n\trequested\x18\x04 \x01(\tR\trequestedB\x92\x01\n#ai.nebius.pub.common.error.v1alpha1B\x11\x43ommonErrorsProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/common/error/v1alpha1\xb8\x01\x01\xd2J\x16\x12\x14migrate to common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.error.v1alpha1.common_errors_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.common.error.v1alpha1B\021CommonErrorsProtoP\001Z:github.com/nebius/gosdk/proto/nebius/common/error/v1alpha1\270\001\001\322J\026\022\024migrate to common/v1'
  _globals['_BADREQUEST']._serialized_start=109
  _globals['_BADREQUEST']._serialized_end=266
  _globals['_BADREQUEST_VIOLATION']._serialized_start=207
  _globals['_BADREQUEST_VIOLATION']._serialized_end=266
  _globals['_BADRESOURCESTATE']._serialized_start=268
  _globals['_BADRESOURCESTATE']._serialized_end=345
  _globals['_RESOURCENOTFOUND']._serialized_start=347
  _globals['_RESOURCENOTFOUND']._serialized_end=398
  _globals['_RESOURCEALREADYEXISTS']._serialized_start=400
  _globals['_RESOURCEALREADYEXISTS']._serialized_end=456
  _globals['_RESOURCECONFLICT']._serialized_start=458
  _globals['_RESOURCECONFLICT']._serialized_end=535
  _globals['_OPERATIONABORTED']._serialized_start=538
  _globals['_OPERATIONABORTED']._serialized_end=679
  _globals['_OUTOFRANGE']._serialized_start=681
  _globals['_OUTOFRANGE']._serialized_end=745
  _globals['_PERMISSIONDENIED']._serialized_start=747
  _globals['_PERMISSIONDENIED']._serialized_end=798
  _globals['_INTERNALERROR']._serialized_start=800
  _globals['_INTERNALERROR']._serialized_end=873
  _globals['_TOOMANYREQUESTS']._serialized_start=875
  _globals['_TOOMANYREQUESTS']._serialized_end=922
  _globals['_QUOTAFAILURE']._serialized_start=925
  _globals['_QUOTAFAILURE']._serialized_end=1138
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=1027
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=1138
# @@protoc_insertion_point(module_scope)
