# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/access.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1anebius/iam/v1/access.proto\x12\rnebius.iam.v1\"\xd9\x02\n\x07\x41\x63\x63ount\x12G\n\x0cuser_account\x18\x01 \x01(\x0b\x32\".nebius.iam.v1.Account.UserAccountH\x00R\x0buserAccount\x12P\n\x0fservice_account\x18\x02 \x01(\x0b\x32%.nebius.iam.v1.Account.ServiceAccountH\x00R\x0eserviceAccount\x12V\n\x11\x61nonymous_account\x18\x03 \x01(\x0b\x32\'.nebius.iam.v1.Account.AnonymousAccountH\x00R\x10\x61nonymousAccount\x1a\x1d\n\x0bUserAccount\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a \n\x0eServiceAccount\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a\x12\n\x10\x41nonymousAccountB\x06\n\x04typeBR\n\x14\x61i.nebius.pub.iam.v1B\x0b\x41\x63\x63\x65ssProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.access_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\013AccessProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _globals['_ACCOUNT']._serialized_start=46
  _globals['_ACCOUNT']._serialized_end=391
  _globals['_ACCOUNT_USERACCOUNT']._serialized_start=300
  _globals['_ACCOUNT_USERACCOUNT']._serialized_end=329
  _globals['_ACCOUNT_SERVICEACCOUNT']._serialized_start=331
  _globals['_ACCOUNT_SERVICEACCOUNT']._serialized_end=363
  _globals['_ACCOUNT_ANONYMOUSACCOUNT']._serialized_start=365
  _globals['_ACCOUNT_ANONYMOUSACCOUNT']._serialized_end=383
# @@protoc_insertion_point(module_scope)
