# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/maintenance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.compute.v1 import maintenance_event_pb2 as nebius_dot_compute_dot_v1_dot_maintenance__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+nebius/compute/v1/maintenance_service.proto\x12\x11nebius.compute.v1\x1a\x18nebius/annotations.proto\x1a)nebius/compute/v1/maintenance_event.proto\"G\n$GetMaintenanceEventByInstanceRequest\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\"w\n\x1cListMaintenanceEventsRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x03 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\"\x82\x01\n\x1dListMaintenanceEventsResponse\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32#.nebius.compute.v1.MaintenanceEventR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x80\x02\n\x12MaintenanceService\x12m\n\rGetByInstance\x12\x37.nebius.compute.v1.GetMaintenanceEventByInstanceRequest\x1a#.nebius.compute.v1.MaintenanceEvent\x12o\n\nListActive\x12/.nebius.compute.v1.ListMaintenanceEventsRequest\x1a\x30.nebius.compute.v1.ListMaintenanceEventsResponse\x1a\n\xbaJ\x07\x63omputeBf\n\x18\x61i.nebius.pub.compute.v1B\x17MaintenanceServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.maintenance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\027MaintenanceServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _MAINTENANCESERVICE._options = None
  _MAINTENANCESERVICE._serialized_options = b'\272J\007compute'
  _globals['_GETMAINTENANCEEVENTBYINSTANCEREQUEST']._serialized_start=135
  _globals['_GETMAINTENANCEEVENTBYINSTANCEREQUEST']._serialized_end=206
  _globals['_LISTMAINTENANCEEVENTSREQUEST']._serialized_start=208
  _globals['_LISTMAINTENANCEEVENTSREQUEST']._serialized_end=327
  _globals['_LISTMAINTENANCEEVENTSRESPONSE']._serialized_start=330
  _globals['_LISTMAINTENANCEEVENTSRESPONSE']._serialized_end=460
  _globals['_MAINTENANCESERVICE']._serialized_start=463
  _globals['_MAINTENANCESERVICE']._serialized_end=719
# @@protoc_insertion_point(module_scope)
