# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/federated_credentials_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import federated_credentials_pb2 as nebius_dot_iam_dot_v1_dot_federated__credentials__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1nebius/iam/v1/federated_credentials_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a)nebius/iam/v1/federated_credentials.proto\"8\n\x1eGetFederatedCredentialsRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"g\n$GetByNameFederatedCredentialsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\xb0\x01\n!CreateFederatedCredentialsRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x43\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.iam.v1.FederatedCredentialsSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xa0\x01\n!UpdateFederatedCredentialsRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.iam.v1.FederatedCredentialsSpecR\x04spec\"\x9a\x01\n\x1fListFederatedCredentialsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x85\x01\n ListFederatedCredentialsResponse\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32#.nebius.iam.v1.FederatedCredentialsR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\";\n!DeleteFederatedCredentialsRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xdf\x04\n\x1b\x46\x65\x64\x65ratedCredentialsService\x12Y\n\x03Get\x12-.nebius.iam.v1.GetFederatedCredentialsRequest\x1a#.nebius.iam.v1.FederatedCredentials\x12\x65\n\tGetByName\x12\x33.nebius.iam.v1.GetByNameFederatedCredentialsRequest\x1a#.nebius.iam.v1.FederatedCredentials\x12g\n\x04List\x12..nebius.iam.v1.ListFederatedCredentialsRequest\x1a/.nebius.iam.v1.ListFederatedCredentialsResponse\x12W\n\x06\x43reate\x12\x30.nebius.iam.v1.CreateFederatedCredentialsRequest\x1a\x1b.nebius.common.v1.Operation\x12W\n\x06Update\x12\x30.nebius.iam.v1.UpdateFederatedCredentialsRequest\x1a\x1b.nebius.common.v1.Operation\x12W\n\x06\x44\x65lete\x12\x30.nebius.iam.v1.DeleteFederatedCredentialsRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamBg\n\x14\x61i.nebius.pub.iam.v1B FederatedCredentialsServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.federated_credentials_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B FederatedCredentialsServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETFEDERATEDCREDENTIALSREQUEST.fields_by_name['id']._options = None
  _GETFEDERATEDCREDENTIALSREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEFEDERATEDCREDENTIALSREQUEST.fields_by_name['parent_id']._options = None
  _GETBYNAMEFEDERATEDCREDENTIALSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEFEDERATEDCREDENTIALSREQUEST.fields_by_name['name']._options = None
  _GETBYNAMEFEDERATEDCREDENTIALSREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _CREATEFEDERATEDCREDENTIALSREQUEST.fields_by_name['metadata']._options = None
  _CREATEFEDERATEDCREDENTIALSREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATEFEDERATEDCREDENTIALSREQUEST.fields_by_name['spec']._options = None
  _CREATEFEDERATEDCREDENTIALSREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['parent_id']._options = None
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEFEDERATEDCREDENTIALSREQUEST.fields_by_name['id']._options = None
  _DELETEFEDERATEDCREDENTIALSREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATEDCREDENTIALSSERVICE._options = None
  _FEDERATEDCREDENTIALSSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_GETFEDERATEDCREDENTIALSREQUEST']._serialized_start=233
  _globals['_GETFEDERATEDCREDENTIALSREQUEST']._serialized_end=289
  _globals['_GETBYNAMEFEDERATEDCREDENTIALSREQUEST']._serialized_start=291
  _globals['_GETBYNAMEFEDERATEDCREDENTIALSREQUEST']._serialized_end=394
  _globals['_CREATEFEDERATEDCREDENTIALSREQUEST']._serialized_start=397
  _globals['_CREATEFEDERATEDCREDENTIALSREQUEST']._serialized_end=573
  _globals['_UPDATEFEDERATEDCREDENTIALSREQUEST']._serialized_start=576
  _globals['_UPDATEFEDERATEDCREDENTIALSREQUEST']._serialized_end=736
  _globals['_LISTFEDERATEDCREDENTIALSREQUEST']._serialized_start=739
  _globals['_LISTFEDERATEDCREDENTIALSREQUEST']._serialized_end=893
  _globals['_LISTFEDERATEDCREDENTIALSRESPONSE']._serialized_start=896
  _globals['_LISTFEDERATEDCREDENTIALSRESPONSE']._serialized_end=1029
  _globals['_DELETEFEDERATEDCREDENTIALSREQUEST']._serialized_start=1031
  _globals['_DELETEFEDERATEDCREDENTIALSREQUEST']._serialized_end=1090
  _globals['_FEDERATEDCREDENTIALSSERVICE']._serialized_start=1093
  _globals['_FEDERATEDCREDENTIALSSERVICE']._serialized_end=1700
# @@protoc_insertion_point(module_scope)
