# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/calculator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.compute.v1 import disk_service_pb2 as nebius_dot_compute_dot_v1_dot_disk__service__pb2
from nebius.api.nebius.compute.v1 import filesystem_service_pb2 as nebius_dot_compute_dot_v1_dot_filesystem__service__pb2
from nebius.api.nebius.compute.v1 import instance_service_pb2 as nebius_dot_compute_dot_v1_dot_instance__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/billing/v1alpha1/calculator.proto\x12\x17nebius.billing.v1alpha1\x1a$nebius/compute/v1/disk_service.proto\x1a*nebius/compute/v1/filesystem_service.proto\x1a(nebius/compute/v1/instance_service.proto\"\xfa\x04\n\x0cResourceSpec\x12^\n\x15\x63ompute_instance_spec\x18\x64 \x01(\x0b\x32(.nebius.compute.v1.CreateInstanceRequestH\x00R\x13\x63omputeInstanceSpec\x12k\n\x1c\x63ompute_instance_update_spec\x18\x65 \x01(\x0b\x32(.nebius.compute.v1.UpdateInstanceRequestH\x00R\x19\x63omputeInstanceUpdateSpec\x12R\n\x11\x63ompute_disk_spec\x18\x66 \x01(\x0b\x32$.nebius.compute.v1.CreateDiskRequestH\x00R\x0f\x63omputeDiskSpec\x12_\n\x18\x63ompute_disk_update_spec\x18g \x01(\x0b\x32$.nebius.compute.v1.UpdateDiskRequestH\x00R\x15\x63omputeDiskUpdateSpec\x12\x64\n\x17\x63ompute_filesystem_spec\x18h \x01(\x0b\x32*.nebius.compute.v1.CreateFilesystemRequestH\x00R\x15\x63omputeFilesystemSpec\x12q\n\x1e\x63ompute_filesystem_update_spec\x18i \x01(\x0b\x32*.nebius.compute.v1.UpdateFilesystemRequestH\x00R\x1b\x63omputeFilesystemUpdateSpecB\x0f\n\rresource_spec\"g\n\x11ResourceGroupCost\x12\x45\n\x07general\x18\n \x01(\x0b\x32).nebius.billing.v1alpha1.GeneralTotalCostH\x00R\x07generalB\x0b\n\tcost_type\"P\n\x10GeneralTotalCost\x12<\n\x05total\x18\x01 \x01(\x0b\x32&.nebius.billing.v1alpha1.CostBreakdownR\x05total\"S\n\x13GeneralResourceCost\x12<\n\x05total\x18\x01 \x01(\x0b\x32&.nebius.billing.v1alpha1.CostBreakdownR\x05total\"F\n\rCostBreakdown\x12\x12\n\x04\x63ost\x18\x02 \x01(\tR\x04\x63ost\x12!\n\x0c\x63ost_rounded\x18\x03 \x01(\tR\x0b\x63ostRoundedBj\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x0f\x43\x61lculatorProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.calculator_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\017CalculatorProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _globals['_RESOURCESPEC']._serialized_start=194
  _globals['_RESOURCESPEC']._serialized_end=828
  _globals['_RESOURCEGROUPCOST']._serialized_start=830
  _globals['_RESOURCEGROUPCOST']._serialized_end=933
  _globals['_GENERALTOTALCOST']._serialized_start=935
  _globals['_GENERALTOTALCOST']._serialized_end=1015
  _globals['_GENERALRESOURCECOST']._serialized_start=1017
  _globals['_GENERALRESOURCECOST']._serialized_end=1100
  _globals['_COSTBREAKDOWN']._serialized_start=1102
  _globals['_COSTBREAKDOWN']._serialized_end=1172
# @@protoc_insertion_point(module_scope)
