# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/resource_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/audit/v2/resource_state.proto\x12\x0fnebius.audit.v2\x1a\x1cgoogle/protobuf/struct.proto\"w\n\rResourceState\x12\x33\n\x08previous\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x08previous\x12\x31\n\x07\x63urrent\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x63urrentB]\n\x16\x61i.nebius.pub.audit.v2B\x12ResourceStateProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.resource_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\022ResourceStateProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_RESOURCESTATE']._serialized_start=87
  _globals['_RESOURCESTATE']._serialized_end=206
# @@protoc_insertion_point(module_scope)
