# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.mysterybox.v1 import secret_pb2 as nebius_dot_mysterybox_dot_v1_dot_secret__pb2
from nebius.api.nebius.mysterybox.v1 import secret_service_pb2 as nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2


class SecretServiceStub(object):
    """A set of methods for managing secrets.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/Create',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/Update',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/Get',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__pb2.Secret.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/GetByName',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.GetSecretByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__pb2.Secret.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/List',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.SerializeToString,
                response_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/Delete',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Undelete = channel.unary_unary(
                '/nebius.mysterybox.v1.SecretService/Undelete',
                request_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.UndeleteSecretRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class SecretServiceServicer(object):
    """A set of methods for managing secrets.
    """

    def Create(self, request, context):
        """Creates a new secret in the specified container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing secret, excluded its Payload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified secret, without its Payload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Returns the specified secret by name, without its Payload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Returns the list of secrets in a specified container, without its Payload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Soft delete secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Undelete(self, request, context):
        """Undelete secret version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.GetSecretRequest.FromString,
                    response_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__pb2.Secret.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.GetSecretByNameRequest.FromString,
                    response_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__pb2.Secret.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.FromString,
                    response_serializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Undelete': grpc.unary_unary_rpc_method_handler(
                    servicer.Undelete,
                    request_deserializer=nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.UndeleteSecretRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.mysterybox.v1.SecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretService(object):
    """A set of methods for managing secrets.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/Create',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/Update',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/Get',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
            nebius_dot_mysterybox_dot_v1_dot_secret__pb2.Secret.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/GetByName',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.GetSecretByNameRequest.SerializeToString,
            nebius_dot_mysterybox_dot_v1_dot_secret__pb2.Secret.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/List',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.SerializeToString,
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/Delete',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Undelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.mysterybox.v1.SecretService/Undelete',
            nebius_dot_mysterybox_dot_v1_dot_secret__service__pb2.UndeleteSecretRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
