# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1alpha1/instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.common.v1alpha1 import operation_service_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1alpha1 import instance_pb2 as nebius_dot_compute_dot_v1alpha1_dot_instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.nebius/compute/v1alpha1/instance_service.proto\x12\x17nebius.compute.v1alpha1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a.nebius/common/v1alpha1/operation_service.proto\x1a&nebius/compute/v1alpha1/instance.proto\"$\n\x12GetInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"o\n\x14ListInstancesRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x92\x01\n\x15\x43reateInstanceRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.compute.v1alpha1.InstanceSpecR\x04spec\"\x92\x01\n\x15UpdateInstanceRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.compute.v1alpha1.InstanceSpecR\x04spec\"\'\n\x15\x44\x65leteInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"x\n\x15ListInstancesResponse\x12\x37\n\x05items\x18\x01 \x03(\x0b\x32!.nebius.compute.v1alpha1.InstanceR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"&\n\x14StartInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"%\n\x13StopInstanceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id2\xfe\x06\n\x0fInstanceService\x12U\n\x03Get\x12+.nebius.compute.v1alpha1.GetInstanceRequest\x1a!.nebius.compute.v1alpha1.Instance\x12R\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a!.nebius.compute.v1alpha1.Instance\x12\x65\n\x04List\x12-.nebius.compute.v1alpha1.ListInstancesRequest\x1a..nebius.compute.v1alpha1.ListInstancesResponse\x12[\n\x06\x43reate\x12..nebius.compute.v1alpha1.CreateInstanceRequest\x1a!.nebius.common.v1alpha1.Operation\x12[\n\x06Update\x12..nebius.compute.v1alpha1.UpdateInstanceRequest\x1a!.nebius.common.v1alpha1.Operation\x12[\n\x06\x44\x65lete\x12..nebius.compute.v1alpha1.DeleteInstanceRequest\x1a!.nebius.common.v1alpha1.Operation\x12Y\n\x05Start\x12-.nebius.compute.v1alpha1.StartInstanceRequest\x1a!.nebius.common.v1alpha1.Operation\x12W\n\x04Stop\x12,.nebius.compute.v1alpha1.StopInstanceRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x7f\n\x16ListOperationsByParent\x12\x35.nebius.common.v1alpha1.ListOperationsByParentRequest\x1a..nebius.common.v1alpha1.ListOperationsResponse\x1a\r\x88\x02\x01\xbaJ\x07\x63omputeBr\n\x1e\x61i.nebius.pub.compute.v1alpha1B\x14InstanceServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\xb8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1alpha1.instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.compute.v1alpha1B\024InstanceServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\270\001\001'
  _INSTANCESERVICE._options = None
  _INSTANCESERVICE._serialized_options = b'\210\002\001\272J\007compute'
  _globals['_GETINSTANCEREQUEST']._serialized_start=262
  _globals['_GETINSTANCEREQUEST']._serialized_end=298
  _globals['_LISTINSTANCESREQUEST']._serialized_start=300
  _globals['_LISTINSTANCESREQUEST']._serialized_end=411
  _globals['_CREATEINSTANCEREQUEST']._serialized_start=414
  _globals['_CREATEINSTANCEREQUEST']._serialized_end=560
  _globals['_UPDATEINSTANCEREQUEST']._serialized_start=563
  _globals['_UPDATEINSTANCEREQUEST']._serialized_end=709
  _globals['_DELETEINSTANCEREQUEST']._serialized_start=711
  _globals['_DELETEINSTANCEREQUEST']._serialized_end=750
  _globals['_LISTINSTANCESRESPONSE']._serialized_start=752
  _globals['_LISTINSTANCESRESPONSE']._serialized_end=872
  _globals['_STARTINSTANCEREQUEST']._serialized_start=874
  _globals['_STARTINSTANCEREQUEST']._serialized_end=912
  _globals['_STOPINSTANCEREQUEST']._serialized_start=914
  _globals['_STOPINSTANCEREQUEST']._serialized_end=951
  _globals['_INSTANCESERVICE']._serialized_start=954
  _globals['_INSTANCESERVICE']._serialized_end=1848
# @@protoc_insertion_point(module_scope)
