# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1alpha1/instance_template.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/mk8s/v1alpha1/instance_template.proto\x12\x14nebius.mk8s.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\"\xc6\x03\n\x08\x44iskSpec\x12-\n\nsize_bytes\x18\x01 \x01(\x03\x42\x0c\xbaH\t\"\x07(\x80\x80\x80\x80\x80\x02H\x00R\tsizeBytes\x12\x33\n\x0esize_kibibytes\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05(\x80\x80\x80 H\x00R\rsizeKibibytes\x12\x32\n\x0esize_mebibytes\x18\x03 \x01(\x03\x42\t\xbaH\x06\"\x04(\x80\x80\x04H\x00R\rsizeMebibytes\x12\x30\n\x0esize_gibibytes\x18\x04 \x01(\x03\x42\x07\xbaH\x04\"\x02(@H\x00R\rsizeGibibytes\x12(\n\x10\x62lock_size_bytes\x18\x05 \x01(\x03R\x0e\x62lockSizeBytes\x12\x41\n\x04type\x18\x06 \x01(\x0e\x32\'.nebius.mk8s.v1alpha1.DiskSpec.DiskTypeB\x04\xbaJ\x01\x07R\x04type\"t\n\x08\x44iskType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bNETWORK_SSD\x10\x01\x12\x0f\n\x0bNETWORK_HDD\x10\x02\x12\x15\n\x11NETWORK_SSD_IO_M3\x10\x03\x12\x1e\n\x1aNETWORK_SSD_NON_REPLICATED\x10\x04\x42\r\n\x04size\x12\x05\xbaH\x02\x08\x01\"\\\n\rResourcesSpec\x12\"\n\x08platform\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\x12\x18\n\x06preset\x18\x02 \x01(\tH\x00R\x06presetB\r\n\x04size\x12\x05\xbaH\x02\x08\x01\x42\x7f\n\x1b\x61i.nebius.pub.mk8s.v1alpha1B\x15InstanceTemplateProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\xb8\x01\x01\xd2J\x0f\x12\rmigrate to v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1alpha1.instance_template_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mk8s.v1alpha1B\025InstanceTemplateProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\270\001\001\322J\017\022\rmigrate to v1'
  _DISKSPEC.oneofs_by_name['size']._options = None
  _DISKSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _DISKSPEC.fields_by_name['size_bytes']._options = None
  _DISKSPEC.fields_by_name['size_bytes']._serialized_options = b'\272H\t\"\007(\200\200\200\200\200\002'
  _DISKSPEC.fields_by_name['size_kibibytes']._options = None
  _DISKSPEC.fields_by_name['size_kibibytes']._serialized_options = b'\272H\007\"\005(\200\200\200 '
  _DISKSPEC.fields_by_name['size_mebibytes']._options = None
  _DISKSPEC.fields_by_name['size_mebibytes']._serialized_options = b'\272H\006\"\004(\200\200\004'
  _DISKSPEC.fields_by_name['size_gibibytes']._options = None
  _DISKSPEC.fields_by_name['size_gibibytes']._serialized_options = b'\272H\004\"\002(@'
  _DISKSPEC.fields_by_name['type']._options = None
  _DISKSPEC.fields_by_name['type']._serialized_options = b'\272J\001\007'
  _RESOURCESSPEC.oneofs_by_name['size']._options = None
  _RESOURCESSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _RESOURCESSPEC.fields_by_name['platform']._options = None
  _RESOURCESSPEC.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _globals['_DISKSPEC']._serialized_start=126
  _globals['_DISKSPEC']._serialized_end=580
  _globals['_DISKSPEC_DISKTYPE']._serialized_start=449
  _globals['_DISKSPEC_DISKTYPE']._serialized_end=565
  _globals['_RESOURCESSPEC']._serialized_start=582
  _globals['_RESOURCESSPEC']._serialized_end=674
# @@protoc_insertion_point(module_scope)
