# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import group_pb2 as nebius_dot_iam_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/iam/v1/group_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x19nebius/iam/v1/group.proto\"\x82\x01\n\x12\x43reateGroupRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.iam.v1.GroupSpecR\x04spec\")\n\x0fGetGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"X\n\x15GetGroupByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x9f\x01\n\x11ListGroupsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"h\n\x12ListGroupsResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x14.nebius.iam.v1.GroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\",\n\x12\x44\x65leteGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x82\x01\n\x12UpdateGroupRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.iam.v1.GroupSpecR\x04spec2\xcb\x03\n\x0cGroupService\x12H\n\x06\x43reate\x12!.nebius.iam.v1.CreateGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12;\n\x03Get\x12\x1e.nebius.iam.v1.GetGroupRequest\x1a\x14.nebius.iam.v1.Group\x12G\n\tGetByName\x12$.nebius.iam.v1.GetGroupByNameRequest\x1a\x14.nebius.iam.v1.Group\x12K\n\x04List\x12 .nebius.iam.v1.ListGroupsRequest\x1a!.nebius.iam.v1.ListGroupsResponse\x12H\n\x06\x44\x65lete\x12!.nebius.iam.v1.DeleteGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12H\n\x06Update\x12!.nebius.iam.v1.UpdateGroupRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamBX\n\x14\x61i.nebius.pub.iam.v1B\x11GroupServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\021GroupServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETGROUPREQUEST.fields_by_name['id']._options = None
  _GETGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETGROUPBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETGROUPBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETGROUPBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETGROUPBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTGROUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTGROUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEGROUPREQUEST.fields_by_name['id']._options = None
  _DELETEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GROUPSERVICE._options = None
  _GROUPSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEGROUPREQUEST']._serialized_start=202
  _globals['_CREATEGROUPREQUEST']._serialized_end=332
  _globals['_GETGROUPREQUEST']._serialized_start=334
  _globals['_GETGROUPREQUEST']._serialized_end=375
  _globals['_GETGROUPBYNAMEREQUEST']._serialized_start=377
  _globals['_GETGROUPBYNAMEREQUEST']._serialized_end=465
  _globals['_LISTGROUPSREQUEST']._serialized_start=468
  _globals['_LISTGROUPSREQUEST']._serialized_end=627
  _globals['_LISTGROUPSRESPONSE']._serialized_start=629
  _globals['_LISTGROUPSRESPONSE']._serialized_end=733
  _globals['_DELETEGROUPREQUEST']._serialized_start=735
  _globals['_DELETEGROUPREQUEST']._serialized_end=779
  _globals['_UPDATEGROUPREQUEST']._serialized_start=782
  _globals['_UPDATEGROUPREQUEST']._serialized_end=912
  _globals['_GROUPSERVICE']._serialized_start=915
  _globals['_GROUPSERVICE']._serialized_end=1374
# @@protoc_insertion_point(module_scope)
