# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/maintenance/v1alpha1/maintenance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.maintenance.v1alpha1 import maintenance_pb2 as nebius_dot_maintenance_dot_v1alpha1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nebius/maintenance/v1alpha1/maintenance_service.proto\x12\x1bnebius.maintenance.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a-nebius/maintenance/v1alpha1/maintenance.proto\">\n\x17ListMaintenancesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\"Z\n\x18ListMaintenancesResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32(.nebius.maintenance.v1alpha1.MaintenanceR\x05items\"/\n\x15GetMaintenanceRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xfa\x01\n\x18UpdateMaintenanceRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12@\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.maintenance.v1alpha1.MaintenanceSpecR\x04spec:T\xbaHQ\x1aO\n\x1bupdate_maintenance.metadata\x12\x19\'metadata\' must have \'id\'\x1a\x15has(this.metadata.id)\"g\n\x19UpdateMaintenanceResponse\x12J\n\x0bmaintenance\x18\x01 \x01(\x0b\x32(.nebius.maintenance.v1alpha1.MaintenanceR\x0bmaintenance2\xfb\x02\n\x12MaintenanceService\x12\x63\n\x03Get\x12\x32.nebius.maintenance.v1alpha1.GetMaintenanceRequest\x1a(.nebius.maintenance.v1alpha1.Maintenance\x12s\n\x04List\x12\x34.nebius.maintenance.v1alpha1.ListMaintenancesRequest\x1a\x35.nebius.maintenance.v1alpha1.ListMaintenancesResponse\x12w\n\x06Update\x12\x35.nebius.maintenance.v1alpha1.UpdateMaintenanceRequest\x1a\x36.nebius.maintenance.v1alpha1.UpdateMaintenanceResponse\x1a\x12\xbaJ\x0fmaintenance.mspBz\n\"ai.nebius.pub.maintenance.v1alpha1B\x17MaintenanceServiceProtoP\x01Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.maintenance.v1alpha1.maintenance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"ai.nebius.pub.maintenance.v1alpha1B\027MaintenanceServiceProtoP\001Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1'
  _LISTMAINTENANCESREQUEST.fields_by_name['parent_id']._options = None
  _LISTMAINTENANCESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETMAINTENANCEREQUEST.fields_by_name['id']._options = None
  _GETMAINTENANCEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEMAINTENANCEREQUEST.fields_by_name['metadata']._options = None
  _UPDATEMAINTENANCEREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEMAINTENANCEREQUEST._options = None
  _UPDATEMAINTENANCEREQUEST._serialized_options = b'\272HQ\032O\n\033update_maintenance.metadata\022\031\'metadata\' must have \'id\'\032\025has(this.metadata.id)'
  _MAINTENANCESERVICE._options = None
  _MAINTENANCESERVICE._serialized_options = b'\272J\017maintenance.msp'
  _globals['_LISTMAINTENANCESREQUEST']._serialized_start=221
  _globals['_LISTMAINTENANCESREQUEST']._serialized_end=283
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_start=285
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_end=375
  _globals['_GETMAINTENANCEREQUEST']._serialized_start=377
  _globals['_GETMAINTENANCEREQUEST']._serialized_end=424
  _globals['_UPDATEMAINTENANCEREQUEST']._serialized_start=427
  _globals['_UPDATEMAINTENANCEREQUEST']._serialized_end=677
  _globals['_UPDATEMAINTENANCERESPONSE']._serialized_start=679
  _globals['_UPDATEMAINTENANCERESPONSE']._serialized_end=782
  _globals['_MAINTENANCESERVICE']._serialized_start=785
  _globals['_MAINTENANCESERVICE']._serialized_end=1164
# @@protoc_insertion_point(module_scope)
