# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v2/access_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v2 import access_key_pb2 as nebius_dot_iam_dot_v2_dot_access__key__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v2/access_key_service.proto\x12\rnebius.iam.v2\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v2/access_key.proto\x1a\x1anebius/iam/v1/access.proto\"\x8a\x01\n\x16\x43reateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v2.AccessKeySpecR\x04spec\"%\n\x13GetAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"+\n\x19GetAccessKeySecretRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"G\n\x1aGetAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"\x88\x01\n\x15ListAccessKeysRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\xa6\x01\n\x1eListAccessKeysByAccountRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountR\x07\x61\x63\x63ount\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x8a\x01\n\x16UpdateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v2.AccessKeySpecR\x04spec\"*\n\x18\x41\x63tivateAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\",\n\x1a\x44\x65\x61\x63tivateAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"L\n\x1f\x41\x63tivateAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"N\n!DeactivateAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"(\n\x16\x44\x65leteAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"J\n\x1d\x44\x65leteAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"d\n\x1aGetAccessKeySecretResponse\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\x12\x1b\n\x06secret\x18\x02 \x01(\tB\x03\xc0J\x01R\x06secret\"p\n\x16ListAccessKeysResponse\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x18.nebius.iam.v2.AccessKeyR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x86\t\n\x10\x41\x63\x63\x65ssKeyService\x12L\n\x06\x43reate\x12%.nebius.iam.v2.CreateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12\x43\n\x03Get\x12\".nebius.iam.v2.GetAccessKeyRequest\x1a\x18.nebius.iam.v2.AccessKey\x12`\n\tGetSecret\x12(.nebius.iam.v2.GetAccessKeySecretRequest\x1a).nebius.iam.v2.GetAccessKeySecretResponse\x12S\n\x04List\x12$.nebius.iam.v2.ListAccessKeysRequest\x1a%.nebius.iam.v2.ListAccessKeysResponse\x12L\n\x06Update\x12%.nebius.iam.v2.UpdateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12L\n\x06\x44\x65lete\x12%.nebius.iam.v2.DeleteAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12P\n\x08\x41\x63tivate\x12\'.nebius.iam.v2.ActivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12T\n\nDeactivate\x12).nebius.iam.v2.DeactivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12\x65\n\rListByAccount\x12-.nebius.iam.v2.ListAccessKeysByAccountRequest\x1a%.nebius.iam.v2.ListAccessKeysResponse\x12Q\n\nGetByAwsId\x12).nebius.iam.v2.GetAccessKeyByAwsIdRequest\x1a\x18.nebius.iam.v2.AccessKey\x12Z\n\rDeleteByAwsId\x12,.nebius.iam.v2.DeleteAccessKeyByAwsIdRequest\x1a\x1b.nebius.common.v1.Operation\x12^\n\x0f\x41\x63tivateByAwsId\x12..nebius.iam.v2.ActivateAccessKeyByAwsIdRequest\x1a\x1b.nebius.common.v1.Operation\x12\x62\n\x11\x44\x65\x61\x63tivateByAwsId\x12\x30.nebius.iam.v2.DeactivateAccessKeyByAwsIdRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamB\\\n\x14\x61i.nebius.pub.iam.v2B\x15\x41\x63\x63\x65ssKeyServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v2.access_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v2B\025AccessKeyServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v2'
  _GETACCESSKEYSECRETRESPONSE.fields_by_name['secret']._options = None
  _GETACCESSKEYSECRETRESPONSE.fields_by_name['secret']._serialized_options = b'\300J\001'
  _ACCESSKEYSERVICE._options = None
  _ACCESSKEYSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEACCESSKEYREQUEST']._serialized_start=211
  _globals['_CREATEACCESSKEYREQUEST']._serialized_end=349
  _globals['_GETACCESSKEYREQUEST']._serialized_start=351
  _globals['_GETACCESSKEYREQUEST']._serialized_end=388
  _globals['_GETACCESSKEYSECRETREQUEST']._serialized_start=390
  _globals['_GETACCESSKEYSECRETREQUEST']._serialized_end=433
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_start=435
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_end=506
  _globals['_LISTACCESSKEYSREQUEST']._serialized_start=509
  _globals['_LISTACCESSKEYSREQUEST']._serialized_end=645
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_start=648
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_end=814
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_start=817
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_end=955
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_start=957
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_end=999
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_start=1001
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_end=1045
  _globals['_ACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_start=1047
  _globals['_ACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_end=1123
  _globals['_DEACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_start=1125
  _globals['_DEACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_end=1203
  _globals['_DELETEACCESSKEYREQUEST']._serialized_start=1205
  _globals['_DELETEACCESSKEYREQUEST']._serialized_end=1245
  _globals['_DELETEACCESSKEYBYAWSIDREQUEST']._serialized_start=1247
  _globals['_DELETEACCESSKEYBYAWSIDREQUEST']._serialized_end=1321
  _globals['_GETACCESSKEYSECRETRESPONSE']._serialized_start=1323
  _globals['_GETACCESSKEYSECRETRESPONSE']._serialized_end=1423
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_start=1425
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_end=1537
  _globals['_ACCESSKEYSERVICE']._serialized_start=1540
  _globals['_ACCESSKEYSERVICE']._serialized_end=2698
# @@protoc_insertion_point(module_scope)
