# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/mlflow/v1alpha1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.msp.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_v1alpha1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/msp/mlflow/v1alpha1/cluster.proto\x12\x1anebius.msp.mlflow.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\x1a!nebius/msp/v1alpha1/cluster.proto\"\xe5\x01\n\x07\x43luster\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x43\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.msp.mlflow.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12M\n\x06status\x18\x03 \x01(\x0b\x32/.nebius.msp.mlflow.v1alpha1.MlflowClusterStatusB\x04\xbaJ\x01\x05R\x06status\"\xea\x02\n\x0b\x43lusterSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12#\n\rpublic_access\x18\x02 \x01(\x08R\x0cpublicAccess\x12-\n\x0e\x61\x64min_username\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\radminUsername\x12\x34\n\x0e\x61\x64min_password\x18\x05 \x01(\tB\r\xbaH\x03\xc8\x01\x01\xbaJ\x01\x04\xc0J\x01R\radminPassword\x12\x34\n\x12service_account_id\x18\x06 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x10serviceAccountId\x12.\n\x13storage_bucket_name\x18\x07 \x01(\tR\x11storageBucketName\x12)\n\nnetwork_id\x18\x08 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnetworkId\x12\x18\n\x04size\x18\t \x01(\tB\x04\xbaJ\x01\x07R\x04sizeJ\x04\x08\x03\x10\x04\"\xaf\x03\n\x13MlflowClusterStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12+\n\x11tracking_endpoint\x18\x03 \x01(\tR\x10trackingEndpoint\x12\x41\n\x1d\x65\x66\x66\x65\x63tive_storage_bucket_name\x18\x04 \x01(\tR\x1a\x65\x66\x66\x65\x63tiveStorageBucketName\x12+\n\x11\x65xperiments_count\x18\x05 \x01(\rR\x10\x65xperimentsCount\x12%\n\x0emlflow_version\x18\x06 \x01(\tR\rmlflowVersion\x12T\n\x12tracking_endpoints\x18\x07 \x01(\x0b\x32%.nebius.msp.mlflow.v1alpha1.EndpointsR\x11trackingEndpoints\"=\n\tEndpoints\x12\x18\n\x07private\x18\x01 \x01(\tR\x07private\x12\x16\n\x06public\x18\x02 \x01(\tR\x06publicBm\n!ai.nebius.pub.msp.mlflow.v1alpha1B\x0c\x43lusterProtoP\x01Z8github.com/nebius/gosdk/proto/nebius/msp/mlflow/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.mlflow.v1alpha1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!ai.nebius.pub.msp.mlflow.v1alpha1B\014ClusterProtoP\001Z8github.com/nebius/gosdk/proto/nebius/msp/mlflow/v1alpha1'
  _CLUSTER.fields_by_name['metadata']._options = None
  _CLUSTER.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTER.fields_by_name['spec']._options = None
  _CLUSTER.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTER.fields_by_name['status']._options = None
  _CLUSTER.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _CLUSTERSPEC.fields_by_name['admin_username']._options = None
  _CLUSTERSPEC.fields_by_name['admin_username']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSPEC.fields_by_name['admin_password']._options = None
  _CLUSTERSPEC.fields_by_name['admin_password']._serialized_options = b'\272H\003\310\001\001\272J\001\004\300J\001'
  _CLUSTERSPEC.fields_by_name['service_account_id']._options = None
  _CLUSTERSPEC.fields_by_name['service_account_id']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSPEC.fields_by_name['network_id']._options = None
  _CLUSTERSPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _CLUSTERSPEC.fields_by_name['size']._options = None
  _CLUSTERSPEC.fields_by_name['size']._serialized_options = b'\272J\001\007'
  _globals['_CLUSTER']._serialized_start=196
  _globals['_CLUSTER']._serialized_end=425
  _globals['_CLUSTERSPEC']._serialized_start=428
  _globals['_CLUSTERSPEC']._serialized_end=790
  _globals['_MLFLOWCLUSTERSTATUS']._serialized_start=793
  _globals['_MLFLOWCLUSTERSTATUS']._serialized_end=1224
  _globals['_ENDPOINTS']._serialized_start=1226
  _globals['_ENDPOINTS']._serialized_end=1287
# @@protoc_insertion_point(module_scope)
