# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.common.v1alpha1 import operation_service_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1alpha1 import gpu_cluster_pb2 as nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2
from nebius.api.nebius.compute.v1alpha1 import gpu_cluster_service_pb2 as nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2


class GpuClusterServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/Get',
                request_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.GetGpuClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2.GpuCluster.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/GetByName',
                request_serializer=nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2.GpuCluster.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/List',
                request_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.ListGpuClustersRequest.SerializeToString,
                response_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.ListGpuClustersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/Create',
                request_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.CreateGpuClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/Update',
                request_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.UpdateGpuClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/Delete',
                request_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.DeleteGpuClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperationsByParent = channel.unary_unary(
                '/nebius.compute.v1alpha1.GpuClusterService/ListOperationsByParent',
                request_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2.ListOperationsByParentRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2.ListOperationsResponse.FromString,
                )


class GpuClusterServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperationsByParent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GpuClusterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.GetGpuClusterRequest.FromString,
                    response_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2.GpuCluster.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.FromString,
                    response_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2.GpuCluster.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.ListGpuClustersRequest.FromString,
                    response_serializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.ListGpuClustersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.CreateGpuClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.UpdateGpuClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.DeleteGpuClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperationsByParent': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperationsByParent,
                    request_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2.ListOperationsByParentRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2.ListOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.compute.v1alpha1.GpuClusterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GpuClusterService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/Get',
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.GetGpuClusterRequest.SerializeToString,
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2.GpuCluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/GetByName',
            nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.SerializeToString,
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2.GpuCluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/List',
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.ListGpuClustersRequest.SerializeToString,
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.ListGpuClustersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/Create',
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.CreateGpuClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/Update',
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.UpdateGpuClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/Delete',
            nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__service__pb2.DeleteGpuClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperationsByParent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1alpha1.GpuClusterService/ListOperationsByParent',
            nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2.ListOperationsByParentRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2.ListOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
