# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/postgresql/v1alpha1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import backup_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_backup__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3nebius/msp/postgresql/v1alpha1/backup_service.proto\x12\x1enebius.msp.postgresql.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a+nebius/msp/postgresql/v1alpha1/backup.proto\x1a\x18nebius/annotations.proto\"^\n\x10GetBackupRequest\x12%\n\ncluster_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tclusterId\x12#\n\tbackup_id\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08\x62\x61\x63kupId\"9\n\x12ListBackupsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\"D\n\x1bListBackupsByClusterRequest\x12%\n\ncluster_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tclusterId\"W\n\x13ListBackupsResponse\x12@\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.nebius.msp.postgresql.v1alpha1.BackupR\x07\x62\x61\x63kups\"<\n\x13\x43reateBackupRequest\x12%\n\ncluster_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tclusterId\"a\n\x13\x44\x65leteBackupRequest\x12%\n\ncluster_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tclusterId\x12#\n\tbackup_id\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08\x62\x61\x63kupId2\xbc\x04\n\rBackupService\x12_\n\x03Get\x12\x30.nebius.msp.postgresql.v1alpha1.GetBackupRequest\x1a&.nebius.msp.postgresql.v1alpha1.Backup\x12o\n\x04List\x12\x32.nebius.msp.postgresql.v1alpha1.ListBackupsRequest\x1a\x33.nebius.msp.postgresql.v1alpha1.ListBackupsResponse\x12\x81\x01\n\rListByCluster\x12;.nebius.msp.postgresql.v1alpha1.ListBackupsByClusterRequest\x1a\x33.nebius.msp.postgresql.v1alpha1.ListBackupsResponse\x12`\n\x06\x43reate\x12\x33.nebius.msp.postgresql.v1alpha1.CreateBackupRequest\x1a!.nebius.common.v1alpha1.Operation\x12`\n\x06\x44\x65lete\x12\x33.nebius.msp.postgresql.v1alpha1.DeleteBackupRequest\x1a!.nebius.common.v1alpha1.Operation\x1a\x11\xbaJ\x0epostgresql.mspB{\n%ai.nebius.pub.msp.postgresql.v1alpha1B\x12\x42\x61\x63kupServiceProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.postgresql.v1alpha1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.postgresql.v1alpha1B\022BackupServiceProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1'
  _GETBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _GETBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _GETBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _GETBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTBACKUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTBACKUPSBYCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _LISTBACKUPSBYCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _DELETEBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\272H\003\310\001\001'
  _BACKUPSERVICE._options = None
  _BACKUPSERVICE._serialized_options = b'\272J\016postgresql.msp'
  _globals['_GETBACKUPREQUEST']._serialized_start=227
  _globals['_GETBACKUPREQUEST']._serialized_end=321
  _globals['_LISTBACKUPSREQUEST']._serialized_start=323
  _globals['_LISTBACKUPSREQUEST']._serialized_end=380
  _globals['_LISTBACKUPSBYCLUSTERREQUEST']._serialized_start=382
  _globals['_LISTBACKUPSBYCLUSTERREQUEST']._serialized_end=450
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=452
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=539
  _globals['_CREATEBACKUPREQUEST']._serialized_start=541
  _globals['_CREATEBACKUPREQUEST']._serialized_end=601
  _globals['_DELETEBACKUPREQUEST']._serialized_start=603
  _globals['_DELETEBACKUPREQUEST']._serialized_end=700
  _globals['_BACKUPSERVICE']._serialized_start=703
  _globals['_BACKUPSERVICE']._serialized_end=1275
# @@protoc_insertion_point(module_scope)
